/*-----------------------
 * state
 -----------------------*/
var expandProperties = {
    "width" : 0,
    "height" : 0,
    "useCustomClose" : false,
    "isModal" : true // read-only in MraidV2
};

var ORIENTATION_PROPERTIES_FORCE_ORIENTATION = {
    "PORTRAIT" : "portrait",
    "LANDSCAPE" : "landscape",
    "NONE" : "none"
};

var orientationProperties = {
    "allowOrientationChange" : true,
    "forceOrientation" : ORIENTATION_PROPERTIES_FORCE_ORIENTATION.NONE
};




/*-----------------------
 * API: methods called by ad
 -----------------------*/
var mraid = {

    listeners: [],

    addEventListener: function(event, listener) {
        if (typeof mraid.listeners[event] === "undefined") {
            mraid.listeners[event] = [];
        }
        console.log("ADD--EVENT:--" + event + "--LISTENER:--" + listener);
        mraid.listeners[event].push(listener);
    },
    
    removeEventListener: function(event, listener) {
        if (typeof mraid.listeners[event] !== "undefined") {
            var i;
            console.log("REMOVE--EVENT:--" + event + "--LISTENER:--" + listener);
            for (i=0; i<mraid.listeners[event].length; i++) {
                if (mraid.listeners[event][i] === listener) {
                    mraid.listeners[event].splice(i, 1);
                }
            }
        }
    },
    
    open: function(url) {
        MraidController.open(url);
    },
    
    close: function() {
        MraidController.close();
    },
    
    getPlacementType: function() {
        return MraidController.getPlacementType();
    },
    
    getState: function() {
        return MraidController.getState();
    },
    
    getVersion: function() {
        return MraidController.getVersion();
    },

    isViewable: function() {
        return MraidController.isViewable();
    },

    useCustomClose: function(customClose) {
        console.log("mraid.useCustomClose " + customClose);
        MraidController.useCustomClose(customClose);
    },
    
    /*--------------------------
        expand implementation
    --------------------------*/
    expand: function(url){
        if (url === undefined) {
            console.log("mraid.expand");
        } else {
           console.log("mraid.expand " + url);
        }

        
        if (url === undefined) {
            MraidController.expand(undefined);
        } else {
            MraidController.expand(url);
        }

    },
    
    getExpandProperties: function() {
        console.log("mraid.getExpandProperties");
        return expandProperties;
    },

    setExpandProperties: function(properties){
        console.log("mraid.setExpandProperties");
        
        var oldUseCustomClose = expandProperties.useCustomClose;
        var props = [ "width", "height", "useCustomClose" ];
        for (var i = 0; i < props.length; i++) {
            var propname = props[i];
            if (properties.hasOwnProperty(propname)) {
                expandProperties[propname] = properties[propname];
            }
        }
        
        // In MRAID v2.0, all expanded ads by definition cover the entire screen,
        // so the only property that the native side has to know about is useCustomClose.
        // (That is, the width and height properties are not needed by the native code.)
        if (expandProperties.useCustomClose !== oldUseCustomClose) {
             mraid.useCustomClose(expandProperties.useCustomClose);
        }
    },
    /*--------------------------
      end expand implementation
    --------------------------*/
    
    getOrientationProperties: function(){
        console.log("mraid.getOrientationProperties");
        return orientationProperties;
    },
    
    setOrientationProperties: function(properties){
        console.log("mraid.setOrientationProperties");
        
        var newOrientationProperties = {};
        newOrientationProperties.allowOrientationChange = orientationProperties.allowOrientationChange,
        newOrientationProperties.forceOrientation = orientationProperties.forceOrientation;
        
        var props = [ "allowOrientationChange", "forceOrientation" ];
        for (var i = 0; i < props.length; i++) {
            var propname = props[i];
            if (properties.hasOwnProperty(propname)) {
                newOrientationProperties[propname] = properties[propname];
            }
        }
        

        if (newOrientationProperties.allowOrientationChange &&
            newOrientationProperties.forceOrientation !== ORIENTATION_PROPERTIES_FORCE_ORIENTATION.NONE) {
            console.log("allowOrientationChange is true but forceOrientation is " + newOrientationProperties.forceOrientation,
                        "setOrientationProperties");
            return;
        }
        
        orientationProperties.allowOrientationChange = newOrientationProperties.allowOrientationChange;
        orientationProperties.forceOrientation = newOrientationProperties.forceOrientation;
        MraidController.setOrientationProperties(JSON.stringify(orientationProperties));
    },
    
    
    
    
    

    onEvent: function(event) {
        console.log("ON--EVENT:--" + event);
        if (typeof mraid.listeners[event] !== "undefined") {
            var i;
            for (i=0; i<mraid.listeners[event].length; i++) {
                var args = Array.prototype.slice.call(arguments);
                args.shift();
                mraid.listeners[event][i].apply(null, args);
            }
        }
    }
};

MraidController.mraidJsLoaded();